# Simple Table Operation Has Very Large Compilation Time with MLJ

**URL:** <https://discourse.julialang.org/t/simple-table-operation-has-very-large-compilation-time-with-mlj/82503>\
**Category:** General Usage\
**Tags:** question, dataframes, mlj, tables\
**Created:** [June 9, 2022, 2:10pm UTC](https://discourse.julialang.org/t/simple-table-operation-has-very-large-compilation-time-with-mlj/82503 "2022-06-09T14:10:25Z")\
**Posts on this page:** 1\
**Page:** 2

<div class="post-metadata">

**Author:** ![ablaom](https://sea2.discourse-cdn.com/julialang/user_avatar/discourse.julialang.org/ablaom/32/4889_2.png) [@ablaom](https://discourse.julialang.org/u/ablaom)\
**Post date:** [June 12, 2022, 10:12pm UTC](https://discourse.julialang.org/t/simple-table-operation-has-very-large-compilation-time-with-mlj/82503/22 "2022-06-12T22:12:44Z")

</div>

Under MLJBase 0.20.5 just released:

```julia
julia> using MLJ
using DataFrames

julia> using DataFrames

julia> @time arr = [[rand(1:10) for i in 1:5] for i in 1:5000];
  0.059180 seconds (200.75 k allocations: 11.360 MiB, 98.87% compilation time)

julia> @time df = DataFrames.DataFrame(arr, :auto)
  0.312929 seconds (844.21 k allocations: 46.372 MiB, 7.70% gc time, 98.93% compilation time)

julia> @time y, X = unpack(df, ==(:x1));
  2.724263 seconds (9.68 M allocations: 596.840 MiB, 5.33% gc time, 99.53% compilation time)

julia> @time y, X = unpack(df, ==(:x1));
  0.014382 seconds (27.59 k allocations: 1.977 MiB)

```

[Previous page](https://discourse.julialang.org/t/simple-table-operation-has-very-large-compilation-time-with-mlj/82503.md?page=1)
